document.addEventListener('DOMContentLoaded', () => {
  // Initialize value displays
  const inputs = document.querySelectorAll('input[type="range"]');
  inputs.forEach(input => {
    const display = input.nextElementSibling;
    display.textContent = input.value;
    
    input.addEventListener('input', () => {
      display.textContent = input.value;
    });
  });

  // Initialize chart
  const ctx = document.getElementById('lossChart').getContext('2d');
  let lossData = {
    labels: [],
    data: []
  };

  function drawChart() {
    ctx.clearRect(0, 0, ctx.canvas.width, ctx.canvas.height);
    
    // Set chart dimensions
    ctx.canvas.width = ctx.canvas.parentNode.offsetWidth;
    ctx.canvas.height = 400;
    
    // Draw axes
    ctx.beginPath();
    ctx.strokeStyle = '#4a90e2';
    ctx.lineWidth = 2;
    ctx.moveTo(50, 350);
    ctx.lineTo(ctx.canvas.width - 50, 350);
    ctx.moveTo(50, 350);
    ctx.lineTo(50, 50);
    ctx.stroke();
    
    // Draw loss curve
    if (lossData.data.length > 1) {
      const xScale = (ctx.canvas.width - 100) / (lossData.data.length - 1);
      const yScale = 300 / Math.max(...lossData.data);
      
      ctx.beginPath();
      ctx.strokeStyle = '#4a90e2';
      ctx.lineWidth = 2;
      
      lossData.data.forEach((value, index) => {
        const x = 50 + (index * xScale);
        const y = 350 - (value * yScale);
        
        if (index === 0) {
          ctx.moveTo(x, y);
        } else {
          ctx.lineTo(x, y);
        }
      });
      
      ctx.stroke();
    }
  }

  // Handle window resize
  window.addEventListener('resize', drawChart);

  // Run experiment button click handler
  document.getElementById('runExperiment').addEventListener('click', async () => {
    const button = document.getElementById('runExperiment');
    button.disabled = true;
    button.textContent = 'Running...';

    // Simulate training process
    lossData = {
      labels: [],
      data: []
    };

    for (let epoch = 0; epoch < 60; epoch++) {
      // Simulate loss calculation
      const loss = Math.exp(-epoch/20) * (1 + Math.random() * 0.2);
      
      lossData.labels.push(epoch);
      lossData.data.push(loss);
      
      drawChart();
      
      // Simulate training delay
      await new Promise(resolve => setTimeout(resolve, 100));
    }

    // Update metrics
    document.getElementById('aucScore').textContent = (0.85 + Math.random() * 0.1).toFixed(4);
    document.getElementById('ksScore').textContent = (0.75 + Math.random() * 0.1).toFixed(4);
    document.getElementById('logLoss').textContent = (0.3 + Math.random() * 0.1).toFixed(4);

    button.disabled = false;
    button.textContent = 'Run Experiment';
  });

  // Initial chart draw
  drawChart();
});
